@@ -1,4 +1,23 @@
 #!/usr/bin/python
+###############################################################################
+#                                                                             #
+# Fireinfo                                                                    #
+# Copyright (C) 2010, 2011 IPFire Team (www.ipfire.org)                       #
+#                                                                             #
+# This program is free software: you can redistribute it and/or modify        #
+# it under the terms of the GNU General Public License as published by        #
+# the Free Software Foundation, either version 3 of the License, or           #
+# (at your option) any later version.                                         #
+#                                                                             #
+# This program is distributed in the hope that it will be useful,             #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
+# GNU General Public License for more details.                                #
+#                                                                             #
+# You should have received a copy of the GNU General Public License           #
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
+#                                                                             #
+###############################################################################
 
 import hashlib
 import json
@@ -10,6 +29,7 @@ import _fireinfo
 import cpu
 import device
 import hypervisor
+import network
 
 PROFILE_VERSION = 0
 
@@ -110,6 +130,13 @@ class System(object):
 			"count" : self.cpu.count				
 		}
 
+		p["network"] = {
+			"green" : self.network.has_green(),
+			"blue" : self.network.has_blue(),
+			"orange" : self.network.has_orange(),
+			"red" : self.network.has_red(),
+		 }
+
 		# Only append hypervisor information if we are virtualized.
 		if self.virtual:
 			p["hypervisor"] = {
@@ -125,9 +152,6 @@ class System(object):
 			"public_id" : self.public_id,
 			"private_id" : self.private_id,
 
-			# XXX just for beta
-			"secret_id" : self._unique_id,
-
 			# Actual profile data
 			"profile" : p,
 		}
@@ -225,6 +249,9 @@ class System(object):
 
 	@property
 	def language(self):
+		"""
+			Return the language code of IPFire or "unknown" if we cannot get it.
+		"""
 		# Return "unknown" if settings file does not exist.
 		filename = "/var/ipfire/main/settings"
 		if not os.path.exists(filename):
@@ -233,19 +260,28 @@ class System(object):
 		with open(filename, "r") as f:
 			for line in f.readlines():
 				key, val = line.split("=", 1)
-				if key=="LANGUAGE":
+				if key == "LANGUAGE":
 					return val.strip()
 
 	@property
 	def release(self):
+		"""
+			Return the system release string.
+		"""
 		return read_from_file("/etc/system-release")
 
 	@property
 	def bios_vendor(self):
+		"""
+			Return the bios vendor name.
+		"""
 		return read_from_file("/sys/class/dmi/id/bios_vendor")
 
 	@property
 	def vendor(self):
+		"""
+			Return the vendor string of this system (if any).
+		"""
 		ret = None
 		for file in ("sys_vendor", "board_vendor", "chassis_vendor",):
 			ret = read_from_file(os.path.join(SYS_CLASS_DMI, file))
@@ -256,6 +292,9 @@ class System(object):
 
 	@property
 	def model(self):
+		"""
+			Return the model string of this system (if any).
+		"""
 		ret = None
 		for file in ("product_name", "board_model", "chassis_model",):
 			ret = read_from_file(os.path.join(SYS_CLASS_DMI, file))
@@ -266,35 +305,53 @@ class System(object):
 
 	@property
 	def memory(self):
+		"""
+			Return the amount of memory in kilobytes.
+		"""
 		with open("/proc/meminfo", "r") as f:
 			firstline = f.readline().strip()
 			return int(firstline.split()[1])
 
 	@property
 	def kernel_release(self):
+		"""
+			Return the kernel release string.
+		"""
 		return os.uname()[2]
 
 	@property
 	def root_disk(self):
+		"""
+			Return the dev node of the root disk.
+		"""
 		with open("/etc/mtab", "r") as f:
-			dev, mountpoint, rest = f.readline().split(" ",2)
+			dev, mountpoint, rest = f.readline().split(" ", 2)
 			if mountpoint == "/":
+				# Cut off /dev
 				dev = dev[5:]
-				# cut off all digits at end of string
+				# Cut off all digits at end of string
 				while dev[-1] in string.digits:
-					dev = dev[:-1]  
-				return dev	
+					dev = dev[:-1]
+
+				return dev
 
 	@property
 	def root_size(self):
-		path="/sys/block/%s/size" %self.root_disk
+		"""
+			Return the size of the root disk in kilobytes.
+		"""
+		path = "/sys/block/%s/size" % self.root_disk
 		if not os.path.exists(path):
 			return
+
 		with open(path, "r") as f:
-			return int(f.readline())*512/1024
+			return int(f.readline()) * 512 / 1024
 
 	@property
 	def root_disk_serial(self):
+		"""
+			Return the serial number of the root disk (if any).
+		"""
 		serial = _fireinfo.get_harddisk_serial("/dev/%s" % self.root_disk)
 
 		if serial:
@@ -302,8 +359,16 @@ class System(object):
 			return serial.strip()
 
 	def scan(self):
-		toscan = (("/sys/bus/pci/devices", device.PCIDevice),
-		("/sys/bus/usb/devices", device.USBDevice))
+		"""
+			Scan for all devices (PCI/USB) in the system and append them
+			to our list.
+		"""
+		self.devices = []
+
+		toscan = (
+			("/sys/bus/pci/devices", device.PCIDevice),
+			("/sys/bus/usb/devices", device.USBDevice)
+		)
 		for path, cls in toscan:
 			if not os.path.exists(path):
 				continue
@@ -319,7 +384,13 @@ class System(object):
 		"""
 		return self.hypervisor.virtual
 
-		
+	@property
+	def network(self):
+		"""
+			Reference to the network class.
+		"""
+		return network.Network()
+
 
 if __name__ == "__main__":
 	s=System()
